pub enum Error {
DBusError(Error),
NoConnection,
IOError(Error),
JSONError(Error),
NotificationNotFound(u32),
ConnectionInitializedTwice,
}Expand description
Enum representing possible errors to happen during the usage of crate::NotificationService.
Variants
DBusError(Error)
D-Bus error. Carries [zbus::Error] inside.
Usually returned if another notification daemon is running on the session bus.
NoConnection
Returned if attempted to call methods that involve D-Bus interaction and have not called
crate::NotificationService::run yet.
IOError(Error)
Returned in case of I/O file errors. Carries std::io::Error.
JSONError(Error)
Returned if JSON parsing of the notification history failed. Carries serde_json::Error.
Usually indicates that the JSON markup is corrupted.
NotificationNotFound(u32)
Returned if the notification with the given ID is not found.
ConnectionInitializedTwice
Returned if crate::NotificationService::run is called more than once.