pub enum Urgency {
Low,
Normal,
Critical,
}Expand description
The urgency level of the notification.
Represents how important is the notification and may affect how it’s displayed in the graphical interface.
Variants
Low
A low level of urgency.
Notification does not require immediate user attention.
Normal
A normal level of urgency.
For example, a notification about new message from a chat app.
Critical
A critical level of urgency.
The notification requires user attention and should stand out from the rest of notifications.