NotificationService

Struct NotificationService 

pub struct NotificationService { /* private fields */ }
A notification daemon that follows XDG Desktop Notifications Specification.

NotificationService implements Clone and can be cloned cheapely since underlying data is shared.

Implementations

Source

impl NotificationService

pub fn new(cache_dir: Option<PathBuf>) -> Result<Self>

Creates a new instance of the service loading the notification history from file.

  • cache_dir - Overrides the default cache directory located at ~/.cache/ignis_notifications.
Errors

Returns Error::IOError if loading notification history from file fails.

pub fn new_in_memory() -> Self

Creates a new instance of the service without any I/O operations.

It doesn’t load the notification history from file and doesn’t save it consequently. This method can not fail and is guaranteed to return the instance.

pub fn settings(&self) -> Settings

Returns an instance of settings that affect behavior of the service.

pub async fn run(&self) -> Result<()>

Runs the service.

You have to call this this method in order to receive notifications and perform operations on them, such as dismissing or invoking actions. It creates D-Bus connection and registers D-Bus interface on the session bus. Must be called only once.

Errors

Returns Error::DBusError, for example, if the name is already taken on the bus.

Returns Error::ConnectionInitializedTwice if this function is called more than once.

pub async fn dismiss_notification(&self, id: u32) -> Result<()>

Dismiss a notification by its ID.

The notification is removed from the history and application that sent the notification is notified through D-Bus. Emits [Event::NotificationClosed] event.

Errors

Returns Error::DBusError.

Returns Error::NotificationNotFound if the notification with such ID is not found.

pub async fn invoke_action( &self, notification_id: u32, action_key: &str, ) -> Result<()>

Invokes an action by its action key and notification ID it belongs to.

Errors

Returns Error::DBusError.

pub fn get_notifications(&self) -> Vec<NotificationHandle>

Returns a vector of notification handles.

pub fn get_notification_by_id(&self, id: u32) -> Option<NotificationHandle>

Returns a notification handle by notification ID.

pub async fn clear_notifications(&self) -> Result<()>

Clears the notification history.

It dismisses each notification and notifies applications.

Warning

It does NOT emit [Event::NotificationClosed] event for each notification.

pub fn on_notified<F>(&self, callback: F) -> usize
where F: Fn(&(u32, NotificationHandle, bool)) + Send + Sync + 'static,

Invokes a callback when a new notification is received.

The following arguments are passed to the callback:

  1. id - The ID of the notification
  2. handle - Notification handle
  3. replace - Whether this notification replaces the old one with the same ID
pub fn on_notification_closed<F>(&self, callback: F) -> usize
where F: Fn(&(u32, CloseReason)) + Send + Sync + 'static,

Invokes a callback when a notification is closed.

The following arguments are passed to the callback:

  1. id - The ID of the notification
  2. reason - The reason why the notification was closed
pub fn on_notify_notifications<F>(&self, callback: F) -> usize
where F: Fn() + Send + Sync + 'static,

Invokes a callback when value of [get_notifications] changes.

It includes arriving of new notifications, closing and clearing notifications.

pub fn on_notifications_cleared<F>(&self, callback: F) -> usize
where F: Fn() + Send + Sync + 'static,

Invokes a callback when notifications are cleared by a call to [clear_notifications].