Settings

Struct Settings 

pub struct Settings { /* private fields */ }
Settings for NotificationService.

This struct provides methods to change behavior of some parts of the service. Settings uses shared ownership for the data, so cloning it is a cheap operation.

Implementations

Source

impl Settings

pub fn follow_xdg_timeout(&self) -> bool

Returns whether to respect XDG Specification for timeout.

If set to false, notifications never expire despite the value of NotificationHandle::timeout(). Otherwise, behavior is based on notification’s timeout:

  • -1 - timeout value is taken from Settings::default_timeout().
  • 0 - the notification never expire
  • >=0 - this timeout is used to expire the notification

Default: True.

pub fn default_timeout(&self) -> u32

Returns the default timeout which is used when a notification doesn’t specify timeout (-1).

Has effect only if Settings::follow_xdg_timeout() and Settings::expire_by_default() are both true.

Default: 3000.

pub fn expire_by_default(&self) -> bool

Returns whether to expire notifications if the timeout is not specified (when timeout is -1).

If true, notifications expire after the timeout defined in Settings::default_timeout().

Default: false.

pub fn set_follow_xdg_timeout(&self, value: bool)

pub fn set_default_timeout(&self, value: u32)

pub fn set_expire_by_default(&self, value: bool)