pub struct ActionHandle { /* private fields */ }Expand description
A handle which represents a notification action.
Notification actions are typically presented as buttons in UI that allow user to interact with the application which sent the notification.
Implementations
Sourceimpl ActionHandle
impl ActionHandle
Sourcepub fn notification_id(&self) -> u32
pub fn notification_id(&self) -> u32
Returns the ID of the notification this action belongs to.
Sourcepub fn label(&self) -> String
pub fn label(&self) -> String
Returns the localized string which should be displayed to the user.
Sourcepub fn action_key(&self) -> String
pub fn action_key(&self) -> String
Returns the identifier of the action.
"default" means that the action is default.
Sourcepub async fn invoke(&self) -> Result<()>
pub async fn invoke(&self) -> Result<()>
Invoke the action.
It is a shortcut to NotificationService::invoke_action.
Errors
Returns Error::DBusError